@@ -111,7 +111,6 @@ public class AuthenticationEndpoint {
         AuthenticationRequestBody authenticationRequestBody = JacksonUtil.parse(rawRequestBody, AuthenticationRequestBody.class);
         validate(authenticationRequestBody);
         String hostname = RequestUtil.getHostHeader(request);
-        String xHostname = RequestUtil.getXHostHeader(request);
         String userAgent = RequestUtil.getUserAgent(request);
         String forwardedFor = RequestUtil.getForwardedForWithRemoteIp(request);
         String proto = RequestUtil.getForwardedProto(request);
@@ -119,9 +118,7 @@ public class AuthenticationEndpoint {
         HostConfiguration configuration = ConfigurationHelper.getConfiguration(hostname);
         RequestUtil.checkUserAgent(userAgent, configuration);
         LoginCredentials credentials = getCredentials(request, authenticationRequestBody)
-                .withHostConfiguration(configuration)
                 .withHost(hostname)
-                .withXHost(xHostname)
                 .withUserAgent(userAgent)
                 .withForwardedFor(forwardedFor)
                 .withForwardedProto(proto)
@@ -129,7 +126,7 @@ public class AuthenticationEndpoint {
         try {
             AuthenticationService authenticationService = authenticationHandler.getAuthenticationService(configuration);
             SessionData sessionData = authenticationService.authenticate(credentials);
-            sessionData = RequestUtil.enhanceSessionData(request, configuration, hostname, xHostname, userAgent, null, null, null, sessionData);
+            sessionData = RequestUtil.enhanceSessionData(request, configuration, hostname, userAgent, null, null, null, sessionData);
             sessionData = configService.addConfiguration(sessionData);
             return buildResponse(sessionData);
         } catch (ApiFacadeException e) {
