@@ -124,6 +124,18 @@ public class RequestUtil {
 
     private static final Pattern USER_AGENT_PATTERN = Pattern.compile("^(.*)\\.(.*)\\.Mail/(\\S*) \\(.*\\)$");
 
+    private static final String HEADER_CACHE_CONTROL = "Cache-control";
+
+    private static final String HEADER_CACHE_CONTROL_VALUE = "no-cache, no-store, must-revalidate";
+
+    private static final String HEADER_EXPIRES = "Expires";
+
+    private static final String HEADER_EXPIRES_VALUE = "0";
+
+    private static final String HEADER_PRAGMA = "Pragma";
+
+    private static final String HEADER_PRAGMA_VALUE = "no-cache";
+
     @SneakyThrows
     public RequestConfiguration createConfiguration() {
         BasicCookieStore cookieStore = new BasicCookieStore();
@@ -244,11 +256,13 @@ public class RequestUtil {
     }
 
     public <T> Response jsonResponse(int statusCode, T responseBody) {
-        return Response.status(statusCode).entity(JacksonUtil.toString(responseBody)).build();
+        ResponseBuilder responseBuilder = Response.status(statusCode).entity(JacksonUtil.toString(responseBody));
+        return nonCachable(responseBuilder).build();
     }
 
     public Response emptyJsonResponse() {
-        return Response.ok().entity("{}").build();
+        ResponseBuilder responseBuilder = Response.ok().entity("{}");
+        return nonCachable(responseBuilder).build();
     }
 
     public <T> Response createCachableResponse(HttpServletRequest request, T responseBody) {
@@ -258,7 +272,14 @@ public class RequestUtil {
         boolean isNotModified = hashValue.equals(ifNoneMatchValue);
         ResponseBuilder responseBuilder = isNotModified ? Response.notModified() : Response.ok(responseBodyStr);
         responseBuilder.header(HEADER_ETAG, hashValue);
-        return responseBuilder.build();
+        return nonCachable(responseBuilder).build();
+    }
+
+    public ResponseBuilder nonCachable(ResponseBuilder responseBuilder) {
+        responseBuilder.header(HEADER_CACHE_CONTROL, HEADER_CACHE_CONTROL_VALUE);
+        responseBuilder.header(HEADER_EXPIRES, HEADER_EXPIRES_VALUE);
+        responseBuilder.header(HEADER_PRAGMA, HEADER_PRAGMA_VALUE);
+        return responseBuilder;
     }
 
     public String getRemoteIp(HttpServletRequest request) {
